@@ -19,7 +19,8 @@ BEGIN {
                     REPORT_MESSAGE_HEADER REPORT_MESSAGE_FAIL_HEADER
                     TEST_FAIL_STAGE REPORT_MISSING_TESTS CPAN_TESTERS_EMAIL
                     REPORT_MISSING_PREREQS MISSING_PREREQS_LIST 
-                    PERL_VERSION_TOO_LOW
+                    REPORT_MESSAGE_FOOTER MISSING_EXTLIBS_LIST
+                    PERL_VERSION_TOO_LOW REPORT_LOADED_PREREQS
                 ];
 }
 
@@ -88,6 +89,9 @@ use constant RELEVANT_TEST_RESULT
                                 my $specific;
                                 for my $platform (keys %OS) {
                                     if( $name =~ /\b$platform\b/i ) {
+                                        # beware the Mac != MAC
+                                        next if($platform eq 'Mac' &&
+                                                $name !~ /\b$platform\b/);
                                         $specific++;
                                         return 1 if
                                             $^O =~ /^(?:$OS{$platform})$/
@@ -107,7 +111,7 @@ use constant NO_TESTS_DEFINED
                             => sub {
                                 my $buffer = shift or return;
                                 if( $buffer =~
-                                  /('?No tests defined for .* extension.\s*$)/m
+                                  /('?No tests defined(?: for .* extension)?.\s*$)/m
                                   and ( $buffer !~ /\*\.t/m and
                                         $buffer !~ /test\.pl/m)
                                 ) { 
@@ -136,36 +140,37 @@ use constant MISSING_PREREQS_LIST
                                 return @list;
                             };
 
+use constant MISSING_EXTLIBS_LIST
+                            => sub {
+                                my $buffer = shift;
+                                my @list = 
+                                    ($buffer =~
+                                        m/No library found for -l([-\w]+)/g);
+
+                                return @list;
+                            };
+
 use constant REPORT_MESSAGE_HEADER
                             => sub {
-                                my ($author,$email) = @_;
+                                my ($version, $author) = @_;
                                 return << ".";
 
-******************************** NOTE ********************************
-The comments below are created mechanically, possibly without manual
-checking by the sender.  As there are many people performing automatic
-tests on each upload to CPAN, it is likely that you will receive
-identical messages about the same problem.
-
-If you believe that the message is mistaken, please reply to the first
-one with correction and/or additional information, and do not take
-it personally.  (We appreciate your patience. :)
-**********************************************************************
-
-Hello, $author! This is a computer-generated error report created
-automatically by CPANPLUS, version $CPANPLUS::Internals::VERSION.  
-Comments from the tester may appear at the end of this report, as well.
+Dear $author,
+    
+This is a computer-generated error report created automatically by
+CPANPLUS, version $version. Testers personal comments may appear 
+at the end of this report.
 
 .
                             };
 
 use constant REPORT_MESSAGE_FAIL_HEADER
                             => sub {
-                                my($version, $stage, $buffer) = @_;
+                                my($stage, $buffer) = @_;
                                 return << ".";
 
-Thanks for uploading your works to CPAN.  However, it appears that
-CPANPLUS encountered problems while testing your distribution.
+Thank you for uploading your work to CPAN.  However, it appears that
+there were some problems testing your distribution.
 
 TEST RESULTS:
 
@@ -178,7 +183,8 @@ $buffer
 
 use constant REPORT_MISSING_PREREQS
                             => sub {
-                                my @missing = @_;
+                                my ($author,$email,@missing) = @_;
+                                $author = ($author && $email) ? "$author ($email)" : 'Your Name Here';
                                 my $modules = join "\n", @missing;
                                 my $prereqs = join "\n", map {"\t'$_'\t=> '0',".
                                     " # or a minimum working version"} @missing;
@@ -195,7 +201,7 @@ As such, adding the prerequisite module(s) to 'PREREQ_PM' in your
 Makefile.PL should solve this problem.  For example:
 
 WriteMakefile(
-    AUTHOR      => 'Your Name Here',
+    AUTHOR      => '$author',
     ... # other information
     PREREQ_PM   => {
 $prereqs
@@ -207,7 +213,7 @@ probe for missing dependencies and install them, ExtUtils::AutoInstall
 at <http://search.cpan.org/dist/ExtUtils-AutoInstall/> may be
 worth a look.
 
-Thanks!
+Thanks! :-)
 
 .
                             };
@@ -215,9 +221,11 @@ Thanks!
 use constant REPORT_MISSING_TESTS
                             => sub {
                                 return << ".";
-Would it be too much to ask for a simple test script in the next
-release, so people can verify which platforms can successfully
-install them, as well as avoid regression bugs?
+RECOMMENDATIONS:
+
+It would be very helpful if you could include even a simple test 
+script in the next release, so people can verify which platforms
+can successfully install them, as well as avoid regression bugs?
 
 A simple 't/use.t' that says:
 
@@ -232,13 +240,58 @@ __END__
 
 would be appreciated.  If you are interested in making a more robust
 test suite, please see the Test::Simple, Test::More and Test::Tutorial
-manpages at <http://search.cpan.org/dist/Test-Simple/>.
+documentation at <http://search.cpan.org/dist/Test-Simple/>.
 
-Thanks!
+Thanks!  :-)
 
 .
                             };
 
+use constant REPORT_LOADED_PREREQS 
+                            => sub {
+                                my $mod = shift;
+                                my $cb  = $mod->parent;
+                                my $prq = $mod->status->prereqs || {};
+                                my @prq = map { $cb->module_tree($_) }
+                                          sort keys %$prq;
+                                
+                                ### no prereqs?
+                                return '' unless @prq;
+
+                                ### some apparently, list what we loaded
+                                my $str = << ".";
+PREREQUISITES:
+
+Here is a list of prerequisites you specified and versions we 
+managed to load:
+                                
+.
+                                $str .= join '', 
+                                        map { sprintf "\t%-30s %8s\n", $_->name,
+                                              $_->installed_version } @prq;
+                                
+                                return $str;
+                            };
+
+use constant REPORT_MESSAGE_FOOTER
+                            => sub {
+                                return << ".";
+
+******************************** NOTE ********************************
+The comments above are created mechanically, possibly without manual
+checking by the sender.  As there are many people performing automatic
+tests on each upload to CPAN, it is likely that you will receive 
+identical messages about the same problem.
+
+If you believe that the message is mistaken, please reply to the first
+one with correction and/or additional informations, and do not take
+it personally.  We appreciate your patience. :)
+**********************************************************************
+
+Additional comments:
+ 
+.
+                             };
 
 1;
 
